pub struct BuildOptions {
pub base_url: Option<String>,
pub output_dir: PathBuf,
pub static_dir: PathBuf,
pub clean_output_dir: bool,
pub assets: AssetsOptions,
pub prefetch: PrefetchOptions,
pub sitemap: SitemapOptions,
pub incremental: bool,
pub cache_dir: PathBuf,
}Expand description
Maudit build options. Should be passed to coronate().
Examples
Default values:
use maudit::{
content_sources, coronate, routes, BuildOptions, BuildOutput,
};
fn main() -> Result<BuildOutput, Box<dyn std::error::Error>> {
coronate(
routes![],
content_sources![],
BuildOptions::default(),
)
}Custom values:
use maudit::{
content_sources, coronate, routes, BuildOptions, BuildOutput, AssetsOptions,
PrefetchOptions, PrefetchStrategy,
};
fn main() -> Result<BuildOutput, Box<dyn std::error::Error>> {
coronate(
routes![],
content_sources![],
BuildOptions {
output_dir: "public".into(),
static_dir: "static".into(),
assets: AssetsOptions {
assets_dir: "_assets".into(),
tailwind_binary_path: "./node_modules/.bin/tailwindcss".into(),
..Default::default()
},
prefetch: PrefetchOptions {
strategy: PrefetchStrategy::Viewport,
..Default::default()
},
..Default::default()
},
)
}Fields
base_url: Option<String>Base URL for the site, e.g. https://example.com or https://example.com/subdir.
This value is used to generate canonical URLs and can be used wherever the full site URL is needed (e.g. in SEO meta tags) through PageContext::base_url in pages.
output_dir: PathBufstatic_dir: PathBufclean_output_dir: boolWhether to clean the output directory before building.
When incremental is true, this is automatically overridden to false
since incremental builds need to preserve previous output.
assets: AssetsOptionsprefetch: PrefetchOptionssitemap: SitemapOptionsOptions for sitemap generation. See SitemapOptions for configuration.
incremental: boolWhether to use incremental builds. When enabled, only pages whose
dependencies have changed will be re-rendered on subsequent builds.
Defaults to true.
cache_dir: PathBufDirectory for build cache storage.
Defaults to {workspace_root}/target/maudit/<binary_name>.
Implementations
Sourceimpl BuildOptions
impl BuildOptions
Sourcepub fn route_assets_options(&self) -> RouteAssetsOptions
pub fn route_assets_options(&self) -> RouteAssetsOptions
Returns the fully resolved assets options, with the output_assets_dir property resolved to be inside output_dir.
e.g. if output_dir is dist and assets.assets_dir is _maudit, output_assets_dir will return dist/_maudit. The user-entered assets.assets_dir is also available and unchanged.